@@ -1,6 +1,6 @@
 # Statistics Menu dialogs
 
-# last modified 2014-08-17 by J. Fox
+# last modified 2022-06-30 by J. Fox
 
 # Dimensional-analysis menu
 
@@ -12,7 +12,7 @@ Reliability <- function () {
 			initialSelection = varPosn(dialog.values$initial.x, "numeric"),
 			title = gettextRcmdr("Variables (pick three or more)"))
 	onOK <- function() {
-		x <- getSelection(xBox)
+		vars <- x <- getSelection(xBox)
 		closeDialog()
 		putDialog("Reliability", list (initial.x = x))
 		if (3 > length(x)) {
@@ -23,6 +23,7 @@ Reliability <- function () {
 		doItAndPrint(paste("reliability(cov(", ActiveDataSet(), 
 						"[,c(", paste(x, collapse = ","), ")], use=\"complete.obs\"))", 
 						sep = ""))
+		insertRmdSection(paste0(gettextRmdHeader("Scale Reliability: "), paste(vars, collapse = ", ")))
 		tkfocus(CommanderWindow())
 	}
 	OKCancelHelp(helpSubject = "reliability", reset = "Reliability", apply = "Reliability")
@@ -126,6 +127,8 @@ principalComponents <- function () {
       }
     }
     doItAndPrint(paste(cmds, commands, "\n})", sep=""))
+    insertRmdSection(paste0(gettextRmdHeader("Principal-Components Analysis: "),
+                            paste(x, collapse = ", ")))
     if (addPC == "1") activeDataSet(.activeDataSet, flushDialogMemory=FALSE)
     tkfocus(CommanderWindow())
   }
@@ -228,6 +231,7 @@ factorAnalysis <- function () {
     }
     if (commands != "") doItAndPrint(paste(command, commands, "\n})", sep=""))
     else doItAndPrint(paste(command, "})", sep=""))
+    insertRmdSection(paste0(gettextRmdHeader("Factor Analysis: "), paste(x, collapse = ", ")))
     if (scores != "none") activeDataSet(.activeDataSet, flushDialogMemory = FALSE)
     tkfocus(CommanderWindow())
   }
@@ -286,16 +290,22 @@ CFA <- function(){
   fit.indices.2 <- c("CFI", "RNI", "IFI", "SRMR", "AICc", "CAIC")
   fit.indices <- c(fit.indices.1, fit.indices.2)
   fitIndicesFrame <- tkframe(optionsTab)
-  checkBoxes(window=fitIndicesFrame, frame="fitIndicesFrame.1", 
-             boxes=fit.indices.1,
-             initialValues=unlist(dialog.values[paste("initial.", fit.indices.1, sep="")]),
-             labels=fit.indices.1,
-             title=gettextRcmdr("Fit Indices"))
-  checkBoxes(window=fitIndicesFrame, frame="fitIndicesFrame.2", 
-             boxes=fit.indices.2,
-             initialValues=unlist(dialog.values[paste("initial.", fit.indices.2, sep="")]),
-             labels=fit.indices.2,
-             title="")
+  # checkBoxes(window=fitIndicesFrame, frame="fitIndicesFrame.1", 
+  #            boxes=fit.indices.1,
+  #            initialValues=unlist(dialog.values[paste("initial.", fit.indices.1, sep="")]),
+  #            labels=fit.indices.1,
+  #            title=gettextRcmdr("Fit Indices"))
+  # checkBoxes(window=fitIndicesFrame, frame="fitIndicesFrame.2", 
+  #            boxes=fit.indices.2,
+  #            initialValues=unlist(dialog.values[paste("initial.", fit.indices.2, sep="")]),
+  #            labels=fit.indices.2,
+  #            title="")
+  checkBoxes(window=optionsFrame, frame="fitIndicesFrame", 
+             boxes=fit.indices,
+             initialValues=unlist(dialog.values[paste("initial.", fit.indices, sep="")]),
+             labels=fit.indices,
+             title=gettextRcmdr("Fit Indices"),
+             columns=4)
   checkBoxes(window=optionsFrame, frame = "robustFrame", boxes = "robust", initialValues = dialog.values$initial.robust, 
              labels = gettextRcmdr("Robust standard errors"), title=" ")
   putRcmdr("factorNumber", 1)
@@ -357,12 +367,13 @@ CFA <- function(){
                      if (robust == 1) "TRUE" else "FALSE", indices,
                      ")\n})", sep="")
     doItAndPrint(command)
+    insertRmdSection(paste0(gettextRmdHeader("Confirmatory Factor Analysis: "), activeDataSet()))
   }
   OKCancelHelp(helpSubject="CFA", reset="CFA", apply="CFA")
   tkgrid(matrixFrame, labelRcmdr(optionsFrame, text="    "), factorCorFrame, sticky="nw")
   tkgrid(identifyFrame, labelRcmdr(optionsFrame, text="    "),  robustFrame, sticky="w")
   tkgrid(optionsFrame, sticky="w")
-  tkgrid(fitIndicesFrame.1, fitIndicesFrame.2, sticky="nw")
+  # tkgrid(fitIndicesFrame.1, fitIndicesFrame.2, sticky="nw")
   tkgrid(fitIndicesFrame, sticky="w")
   tkgrid(getFrame(xBox), sticky="w")
   tkgrid(labelRcmdr(dataTab, text=""))
